@@ -1,16 +1,15 @@
 /*
  *
- *  This file is part of MUMPS 5.3.5, released
- *  on Thu Oct 22 09:29:08 UTC 2020
+ *  This file is part of MUMPS 5.2.1, released
+ *  on Fri Jun 14 14:46:05 UTC 2019
  *
  *
- *  Copyright 1991-2020 CERFACS, CNRS, ENS Lyon, INP Toulouse, Inria,
+ *  Copyright 1991-2019 CERFACS, CNRS, ENS Lyon, INP Toulouse, Inria,
  *  Mumps Technologies, University of Bordeaux.
  *
  *  This version of MUMPS is provided to you free of charge. It is
- *  released under the CeCILL-C license 
- *  (see doc/CeCILL-C_V1-en.txt, doc/CeCILL-C_V1-fr.txt, and
- *  https://cecill.info/licences/Licence_CeCILL-C_V1-en.html)
+ *  released under the CeCILL-C license:
+ *  http://www.cecill.info/licences/Licence_CeCILL-C_V1-en.html
  *
  */
 #ifndef MUMPS_COMMON_H
@@ -38,16 +37,16 @@
 # define F_SYMBOL(lower_case,upper_case) mumps_##lower_case
 #endif
 MUMPS_INT*
-mumps_get_mapping();
+mumps_get_mapping(void);
 #define MUMPS_ASSIGN_MAPPING \
     F_SYMBOL(assign_mapping,ASSIGN_MAPPING)
 void MUMPS_CALL
 MUMPS_ASSIGN_MAPPING(MUMPS_INT *f77mapping);
 #define MUMPS_NULLIFY_C_MAPPING F_SYMBOL(nullify_c_mapping,NULLIFY_C_MAPPING)
 void MUMPS_CALL
-MUMPS_NULLIFY_C_MAPPING();
+MUMPS_NULLIFY_C_MAPPING(void);
 MUMPS_INT*
-mumps_get_pivnul_list();
+mumps_get_pivnul_list(void);
 #define MUMPS_ASSIGN_PIVNUL_LIST \
     F_SYMBOL(assign_pivnul_list,ASSIGN_PIVNUL_LIST)
 void MUMPS_CALL
@@ -55,9 +54,9 @@ MUMPS_ASSIGN_PIVNUL_LIST(MUMPS_INT *f77pivnul_list);
 #define MUMPS_NULLIFY_C_PIVNUL_LIST \
     F_SYMBOL(nullify_c_pivnul_list,NULLIFY_C_PIVNUL_LIST)
 void MUMPS_CALL
-MUMPS_NULLIFY_C_PIVNUL_LIST();
+MUMPS_NULLIFY_C_PIVNUL_LIST(void);
 MUMPS_INT*
-mumps_get_uns_perm();
+mumps_get_uns_perm(void);
 #define MUMPS_ASSIGN_UNS_PERM \
     F_SYMBOL(assign_uns_perm,ASSIGN_UNS_PERM)
 void MUMPS_CALL
@@ -65,9 +64,9 @@ MUMPS_ASSIGN_UNS_PERM(MUMPS_INT *f77sym_perm);
 #define MUMPS_NULLIFY_C_UNS_PERM \
     F_SYMBOL(nullify_c_uns_perm,NULLIFY_C_UNS_PERM)
 void MUMPS_CALL
-MUMPS_NULLIFY_C_UNS_PERM();
+MUMPS_NULLIFY_C_UNS_PERM(void);
 MUMPS_INT*
-mumps_get_sym_perm();
+mumps_get_sym_perm(void);
 #define MUMPS_ASSIGN_SYM_PERM \
     F_SYMBOL(assign_sym_perm,ASSIGN_SYM_PERM)
 void MUMPS_CALL
@@ -75,7 +74,7 @@ MUMPS_ASSIGN_SYM_PERM(MUMPS_INT * f77sym_perm);
 #define MUMPS_NULLIFY_C_SYM_PERM \
     F_SYMBOL(nullify_c_sym_perm,NULLIFY_C_SYM_PERM)
 void MUMPS_CALL
-MUMPS_NULLIFY_C_SYM_PERM();
+MUMPS_NULLIFY_C_SYM_PERM(void);
 #define MUMPS_ICOPY_32TO64_64C_IP_C \
     F_SYMBOL(icopy_32to64_64c_ip_c,ICOPY_32TO64_64C_IP_C)
 void MUMPS_CALL
